Module: Trek::Hooks
- Extended by:
- ActiveSupport::Concern
- Included in:
- ResourceController
- Defined in:
- app/controllers/concerns/trek/hooks.rb
Instance Method Summary collapse
-
#create_hook ⇒ Object
The methods below can be overridden in controllers to customize the actions behavior.
- #destroy_hook ⇒ Object
- #update_hook ⇒ Object
Instance Method Details
#create_hook ⇒ Object
The methods below can be overridden in controllers to customize the actions behavior.
7 8 |
# File 'app/controllers/concerns/trek/hooks.rb', line 7 def create_hook end |
#destroy_hook ⇒ Object
13 14 |
# File 'app/controllers/concerns/trek/hooks.rb', line 13 def destroy_hook end |
#update_hook ⇒ Object
10 11 |
# File 'app/controllers/concerns/trek/hooks.rb', line 10 def update_hook end |