Module: Trek::Notices
- Extended by:
- ActiveSupport::Concern
- Included in:
- ResourceController
- Defined in:
- app/controllers/concerns/trek/notices.rb
Instance Method Summary collapse
-
#create_notice ⇒ Object
The methods below can be overridden in controllers to customize the notices behavior.
- #destroy_notice ⇒ Object
- #update_notice ⇒ Object
Instance Method Details
#create_notice ⇒ Object
The methods below can be overridden in controllers to customize the notices behavior.
7 8 9 |
# File 'app/controllers/concerns/trek/notices.rb', line 7 def create_notice t("admin.#{model_collection}.create.success") end |
#destroy_notice ⇒ Object
15 16 17 |
# File 'app/controllers/concerns/trek/notices.rb', line 15 def destroy_notice t("admin.#{model_collection}.destroy.success") end |
#update_notice ⇒ Object
11 12 13 |
# File 'app/controllers/concerns/trek/notices.rb', line 11 def update_notice t("admin.#{model_collection}.update.success") end |