Module: Trek::Redirections
- Extended by:
- ActiveSupport::Concern
- Included in:
- ResourceController
- Defined in:
- app/controllers/concerns/trek/redirections.rb
Instance Method Summary collapse
-
#create_success_redirect ⇒ Object
The methods below can be overridden in controllers to customize the redirection behavior.
- #destroy_success_redirect ⇒ Object
- #success_redirect ⇒ Object
- #update_success_redirect ⇒ Object
Instance Method Details
#create_success_redirect ⇒ Object
The methods below can be overridden in controllers to customize the redirection behavior.
7 8 9 |
# File 'app/controllers/concerns/trek/redirections.rb', line 7 def create_success_redirect success_redirect end |
#destroy_success_redirect ⇒ Object
15 16 17 |
# File 'app/controllers/concerns/trek/redirections.rb', line 15 def destroy_success_redirect success_redirect end |
#success_redirect ⇒ Object
19 20 21 |
# File 'app/controllers/concerns/trek/redirections.rb', line 19 def success_redirect [:admin, *model_collection_route] end |
#update_success_redirect ⇒ Object
11 12 13 |
# File 'app/controllers/concerns/trek/redirections.rb', line 11 def update_success_redirect success_redirect end |