Class: Fragment
- Inherits:
-
ApplicationRecord
- Object
- ApplicationRecord
- Fragment
- Includes:
- Trek::Contentable, Trek::Keyable, Trek::Translatable
- Defined in:
- lib/generators/trek/templates/models/fragment.rb
Overview
‘Fragment` is a chunk of content that can be used anywhere on the website, and can be edited from the admin panel.
Instance Method Summary collapse
Methods included from Trek::Contentable
#content_text, #formatted_content, #parsed_content, #prosemirror_content?
Instance Method Details
#to_s ⇒ Object
21 22 23 |
# File 'lib/generators/trek/templates/models/fragment.rb', line 21 def to_s [namespace, key].join(".") end |