Class: PagePath
- Inherits:
-
ApplicationRecord
- Object
- ApplicationRecord
- PagePath
- Includes:
- Trek::Translatable
- Defined in:
- lib/generators/trek/templates/models/page_path.rb
Overview
‘PagePath` represents a path to a given `Page`. It can be the current path, or a former path. This allows to redirect old paths to the current path.